==> istio-model-v1alpha3-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/SidecarSpecBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SidecarSpecBuilder extends SidecarSpecFluentImpl<SidecarSpecBuilder> implements VisitableBuilder<SidecarSpec,SidecarSpecBuilder>{
  public SidecarSpecBuilder() {
    this(false);
  }
  public SidecarSpecBuilder(Boolean validationEnabled) {
    this(new SidecarSpec(), validationEnabled);
  }
  public SidecarSpecBuilder(SidecarSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public SidecarSpecBuilder(SidecarSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SidecarSpec(), validationEnabled);
  }
  public SidecarSpecBuilder(SidecarSpecFluent<?> fluent,SidecarSpec instance) {
    this(fluent, instance, false);
  }
  public SidecarSpecBuilder(SidecarSpecFluent<?> fluent,SidecarSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withEgress(instance.getEgress());
      fluent.withIngress(instance.getIngress());
      fluent.withOutboundTrafficPolicy(instance.getOutboundTrafficPolicy());
      fluent.withWorkloadSelector(instance.getWorkloadSelector());
    }
    this.validationEnabled = validationEnabled; 
  }
  public SidecarSpecBuilder(SidecarSpec instance) {
    this(instance,false);
  }
  public SidecarSpecBuilder(SidecarSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withEgress(instance.getEgress());
      this.withIngress(instance.getIngress());
      this.withOutboundTrafficPolicy(instance.getOutboundTrafficPolicy());
      this.withWorkloadSelector(instance.getWorkloadSelector());
    }
    this.validationEnabled = validationEnabled; 
  }
  SidecarSpecFluent<?> fluent;
  Boolean validationEnabled;
  public SidecarSpec build() {
    SidecarSpec buildable = new SidecarSpec(fluent.getEgress(),fluent.getIngress(),fluent.getOutboundTrafficPolicy(),fluent.getWorkloadSelector());
    return buildable;
  }
  
}

==> istio-model-v1alpha3-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/SidecarSpecBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SidecarSpecBuilder extends SidecarSpecFluent<SidecarSpecBuilder> implements VisitableBuilder<SidecarSpec,SidecarSpecBuilder>{
  public SidecarSpecBuilder() {
    this(false);
  }
  public SidecarSpecBuilder(Boolean validationEnabled) {
    this(new SidecarSpec(), validationEnabled);
  }
  public SidecarSpecBuilder(SidecarSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public SidecarSpecBuilder(SidecarSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SidecarSpec(), validationEnabled);
  }
  public SidecarSpecBuilder(SidecarSpecFluent<?> fluent,SidecarSpec instance) {
    this(fluent, instance, false);
  }
  public SidecarSpecBuilder(SidecarSpecFluent<?> fluent,SidecarSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new SidecarSpec());

    if (instance != null) {
      fluent.withEgress(instance.getEgress());
      fluent.withIngress(instance.getIngress());
      fluent.withOutboundTrafficPolicy(instance.getOutboundTrafficPolicy());
      fluent.withWorkloadSelector(instance.getWorkloadSelector());
      fluent.withEgress(instance.getEgress());
      fluent.withIngress(instance.getIngress());
      fluent.withOutboundTrafficPolicy(instance.getOutboundTrafficPolicy());
      fluent.withWorkloadSelector(instance.getWorkloadSelector());
    }
    this.validationEnabled = validationEnabled; 
  }
  public SidecarSpecBuilder(SidecarSpec instance) {
    this(instance,false);
  }
  public SidecarSpecBuilder(SidecarSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new SidecarSpec());

    if (instance != null) {
      this.withEgress(instance.getEgress());
      this.withIngress(instance.getIngress());
      this.withOutboundTrafficPolicy(instance.getOutboundTrafficPolicy());
      this.withWorkloadSelector(instance.getWorkloadSelector());
      this.withEgress(instance.getEgress());
      this.withIngress(instance.getIngress());
      this.withOutboundTrafficPolicy(instance.getOutboundTrafficPolicy());
      this.withWorkloadSelector(instance.getWorkloadSelector());
    }
    this.validationEnabled = validationEnabled; 
  }
  SidecarSpecFluent<?> fluent;
  Boolean validationEnabled;
  public SidecarSpec build() {
    SidecarSpec buildable = new SidecarSpec(fluent.buildEgress(),fluent.buildIngress(),fluent.buildOutboundTrafficPolicy(),fluent.buildWorkloadSelector());
    return buildable;
  }
  
}
